# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class LlmLLMKnowledgeIngestionJobStatusUpdateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_by_id': 'int',
        'input_yaml_serialized': 'str',
        'job_number': 'int',
        'llm_knowledge_id': 'int',
        'status': 'str',
        'status_message': 'str'
    }

    attribute_map = {
        'created_by_id': 'createdByID',
        'input_yaml_serialized': 'inputYamlSerialized',
        'job_number': 'jobNumber',
        'llm_knowledge_id': 'llmKnowledgeID',
        'status': 'status',
        'status_message': 'statusMessage'
    }

    def __init__(self, created_by_id=None, input_yaml_serialized=None, job_number=None, llm_knowledge_id=None, status=None, status_message=None, local_vars_configuration=None):  # noqa: E501
        """LlmLLMKnowledgeIngestionJobStatusUpdateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_by_id = None
        self._input_yaml_serialized = None
        self._job_number = None
        self._llm_knowledge_id = None
        self._status = None
        self._status_message = None
        self.discriminator = None

        if created_by_id is not None:
            self.created_by_id = created_by_id
        if input_yaml_serialized is not None:
            self.input_yaml_serialized = input_yaml_serialized
        if job_number is not None:
            self.job_number = job_number
        if llm_knowledge_id is not None:
            self.llm_knowledge_id = llm_knowledge_id
        if status is not None:
            self.status = status
        if status_message is not None:
            self.status_message = status_message

    @property
    def created_by_id(self):
        """Gets the created_by_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501


        :return: The created_by_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """Sets the created_by_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.


        :param created_by_id: The created_by_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :type created_by_id: int
        """

        self._created_by_id = created_by_id

    @property
    def input_yaml_serialized(self):
        """Gets the input_yaml_serialized of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501


        :return: The input_yaml_serialized of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._input_yaml_serialized

    @input_yaml_serialized.setter
    def input_yaml_serialized(self, input_yaml_serialized):
        """Sets the input_yaml_serialized of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.


        :param input_yaml_serialized: The input_yaml_serialized of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :type input_yaml_serialized: str
        """

        self._input_yaml_serialized = input_yaml_serialized

    @property
    def job_number(self):
        """Gets the job_number of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501


        :return: The job_number of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._job_number

    @job_number.setter
    def job_number(self, job_number):
        """Sets the job_number of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.


        :param job_number: The job_number of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :type job_number: int
        """

        self._job_number = job_number

    @property
    def llm_knowledge_id(self):
        """Gets the llm_knowledge_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501


        :return: The llm_knowledge_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._llm_knowledge_id

    @llm_knowledge_id.setter
    def llm_knowledge_id(self, llm_knowledge_id):
        """Sets the llm_knowledge_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.


        :param llm_knowledge_id: The llm_knowledge_id of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :type llm_knowledge_id: int
        """

        self._llm_knowledge_id = llm_knowledge_id

    @property
    def status(self):
        """Gets the status of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501


        :return: The status of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.


        :param status: The status of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def status_message(self):
        """Gets the status_message of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501


        :return: The status_message of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """Sets the status_message of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.


        :param status_message: The status_message of this LlmLLMKnowledgeIngestionJobStatusUpdateResponse.  # noqa: E501
        :type status_message: str
        """

        self._status_message = status_message

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LlmLLMKnowledgeIngestionJobStatusUpdateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LlmLLMKnowledgeIngestionJobStatusUpdateResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from openapi_client.api_client import ApiClient
from openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ExecAPIV1Api(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def l_lm_knowledge_ingestion_config_read_api(self, **kwargs):  # noqa: E501
        """l_lm_knowledge_ingestion_config_read_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_knowledge_ingestion_config_read_api(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LlmLLMKnowledgeIngestionConfigReadResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.l_lm_knowledge_ingestion_config_read_api_with_http_info(**kwargs)  # noqa: E501

    def l_lm_knowledge_ingestion_config_read_api_with_http_info(self, **kwargs):  # noqa: E501
        """l_lm_knowledge_ingestion_config_read_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_knowledge_ingestion_config_read_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LlmLLMKnowledgeIngestionConfigReadResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method l_lm_knowledge_ingestion_config_read_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "LlmLLMKnowledgeIngestionConfigReadResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/llm/ingestion_config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def l_lm_knowledge_retriever_config_read_api(self, **kwargs):  # noqa: E501
        """l_lm_knowledge_retriever_config_read_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_knowledge_retriever_config_read_api(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LlmLLMKnowledgeRetrieverConfigReadResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.l_lm_knowledge_retriever_config_read_api_with_http_info(**kwargs)  # noqa: E501

    def l_lm_knowledge_retriever_config_read_api_with_http_info(self, **kwargs):  # noqa: E501
        """l_lm_knowledge_retriever_config_read_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_knowledge_retriever_config_read_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LlmLLMKnowledgeRetrieverConfigReadResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method l_lm_knowledge_retriever_config_read_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "LlmLLMKnowledgeRetrieverConfigReadResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/llm/retriever_config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def l_lm_workflow_workload_read_configuration_api(self, **kwargs):  # noqa: E501
        """l_lm_workflow_workload_read_configuration_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_workflow_workload_read_configuration_api(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LlmLLMWorkflowWorkloadReadConfigurationResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.l_lm_workflow_workload_read_configuration_api_with_http_info(**kwargs)  # noqa: E501

    def l_lm_workflow_workload_read_configuration_api_with_http_info(self, **kwargs):  # noqa: E501
        """l_lm_workflow_workload_read_configuration_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_workflow_workload_read_configuration_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LlmLLMWorkflowWorkloadReadConfigurationResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method l_lm_workflow_workload_read_configuration_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "LlmLLMWorkflowWorkloadReadConfigurationResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/llm/workflow_config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def l_lm_workflow_workload_read_test_configuration_api(self, **kwargs):  # noqa: E501
        """l_lm_workflow_workload_read_test_configuration_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_workflow_workload_read_test_configuration_api(async_req=True)
        >>> result = thread.get()

        :param llm_workflow_workload_read_test_configuration_api_input:
        :type llm_workflow_workload_read_test_configuration_api_input: LLMWorkflowWorkloadReadTestConfigurationAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LlmLLMWorkflowWorkloadReadTestConfigurationResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.l_lm_workflow_workload_read_test_configuration_api_with_http_info(**kwargs)  # noqa: E501

    def l_lm_workflow_workload_read_test_configuration_api_with_http_info(self, **kwargs):  # noqa: E501
        """l_lm_workflow_workload_read_test_configuration_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lm_workflow_workload_read_test_configuration_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param llm_workflow_workload_read_test_configuration_api_input:
        :type llm_workflow_workload_read_test_configuration_api_input: LLMWorkflowWorkloadReadTestConfigurationAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LlmLLMWorkflowWorkloadReadTestConfigurationResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'llm_workflow_workload_read_test_configuration_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method l_lm_workflow_workload_read_test_configuration_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'llm_workflow_workload_read_test_configuration_api_input' in local_var_params:
            body_params = local_var_params['llm_workflow_workload_read_test_configuration_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "LlmLLMWorkflowWorkloadReadTestConfigurationResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/llm/workflow_test_config', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def l_lmapi_key_verify_api(self, **kwargs):  # noqa: E501
        """l_lmapi_key_verify_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lmapi_key_verify_api(async_req=True)
        >>> result = thread.get()

        :param llmapi_key_verify_api_input:
        :type llmapi_key_verify_api_input: LLMAPIKeyVerifyAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LlmLLMAPIKeyVerifyResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.l_lmapi_key_verify_api_with_http_info(**kwargs)  # noqa: E501

    def l_lmapi_key_verify_api_with_http_info(self, **kwargs):  # noqa: E501
        """l_lmapi_key_verify_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.l_lmapi_key_verify_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param llmapi_key_verify_api_input:
        :type llmapi_key_verify_api_input: LLMAPIKeyVerifyAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LlmLLMAPIKeyVerifyResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'llmapi_key_verify_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method l_lmapi_key_verify_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'llmapi_key_verify_api_input' in local_var_params:
            body_params = local_var_params['llmapi_key_verify_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "LlmLLMAPIKeyVerifyResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/llm/keys/verify', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def model_service_revision_health_api(self, **kwargs):  # noqa: E501
        """model_service_revision_health_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_service_revision_health_api(async_req=True)
        >>> result = thread.get()

        :param model_service_revision_health_api_input:
        :type model_service_revision_health_api_input: ModelServiceRevisionHealthAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelserviceModelServiceRevisionHealthResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.model_service_revision_health_api_with_http_info(**kwargs)  # noqa: E501

    def model_service_revision_health_api_with_http_info(self, **kwargs):  # noqa: E501
        """model_service_revision_health_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_service_revision_health_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param model_service_revision_health_api_input:
        :type model_service_revision_health_api_input: ModelServiceRevisionHealthAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ModelserviceModelServiceRevisionHealthResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'model_service_revision_health_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_service_revision_health_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'model_service_revision_health_api_input' in local_var_params:
            body_params = local_var_params['model_service_revision_health_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "ModelserviceModelServiceRevisionHealthResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/modelservice/health', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def model_service_revision_pod_exit_api(self, **kwargs):  # noqa: E501
        """model_service_revision_pod_exit_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_service_revision_pod_exit_api(async_req=True)
        >>> result = thread.get()

        :param model_service_revision_pod_exit_api_input:
        :type model_service_revision_pod_exit_api_input: ModelServiceRevisionPodExitAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.model_service_revision_pod_exit_api_with_http_info(**kwargs)  # noqa: E501

    def model_service_revision_pod_exit_api_with_http_info(self, **kwargs):  # noqa: E501
        """model_service_revision_pod_exit_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_service_revision_pod_exit_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param model_service_revision_pod_exit_api_input:
        :type model_service_revision_pod_exit_api_input: ModelServiceRevisionPodExitAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'model_service_revision_pod_exit_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_service_revision_pod_exit_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'model_service_revision_pod_exit_api_input' in local_var_params:
            body_params = local_var_params['model_service_revision_pod_exit_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "object",
        }

        return self.api_client.call_api(
            '/exec/v1/modelservice/exit', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def model_service_revision_workload_join_api(self, **kwargs):  # noqa: E501
        """model_service_revision_workload_join_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_service_revision_workload_join_api(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelserviceModelServiceRevisionWorkloadJoinResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.model_service_revision_workload_join_api_with_http_info(**kwargs)  # noqa: E501

    def model_service_revision_workload_join_api_with_http_info(self, **kwargs):  # noqa: E501
        """model_service_revision_workload_join_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_service_revision_workload_join_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ModelserviceModelServiceRevisionWorkloadJoinResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_service_revision_workload_join_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "ModelserviceModelServiceRevisionWorkloadJoinResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/modelservice/join', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_done_api(self, **kwargs):  # noqa: E501
        """run_execution_done_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_done_api(async_req=True)
        >>> result = thread.get()

        :param run_execution_done_api_input:
        :type run_execution_done_api_input: RunExecutionDoneAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunRunExecutionDoneResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_done_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_done_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_done_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_done_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param run_execution_done_api_input:
        :type run_execution_done_api_input: RunExecutionDoneAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunRunExecutionDoneResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'run_execution_done_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_done_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'run_execution_done_api_input' in local_var_params:
            body_params = local_var_params['run_execution_done_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "RunRunExecutionDoneResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/run/done', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_exit_api(self, **kwargs):  # noqa: E501
        """run_execution_exit_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_exit_api(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunRunExecutionExitResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_exit_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_exit_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_exit_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_exit_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunRunExecutionExitResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_exit_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "RunRunExecutionExitResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/run/exit', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_get_code_ref_api(self, path, **kwargs):  # noqa: E501
        """run_execution_get_code_ref_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_get_code_ref_api(path, async_req=True)
        >>> result = thread.get()

        :param path: (required)
        :type path: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseCodeRefsV2
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_get_code_ref_api_with_http_info(path, **kwargs)  # noqa: E501

    def run_execution_get_code_ref_api_with_http_info(self, path, **kwargs):  # noqa: E501
        """run_execution_get_code_ref_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_get_code_ref_api_with_http_info(path, async_req=True)
        >>> result = thread.get()

        :param path: (required)
        :type path: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseCodeRefsV2, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'path'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_get_code_ref_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'path' is set
        if self.api_client.client_side_validation and local_var_params.get('path') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `path` when calling `run_execution_get_code_ref_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get('path') is not None:  # noqa: E501
            query_params.append(('path', local_var_params['path']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "ResponseCodeRefsV2",
        }

        return self.api_client.call_api(
            '/exec/v1/run/code', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_get_plot_volume_api(self, **kwargs):  # noqa: E501
        """run_execution_get_plot_volume_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_get_plot_volume_api(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunRunExecutionGetPlotVolumeResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_get_plot_volume_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_get_plot_volume_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_get_plot_volume_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_get_plot_volume_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunRunExecutionGetPlotVolumeResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_get_plot_volume_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "RunRunExecutionGetPlotVolumeResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/run/plot_volume', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_health_api(self, **kwargs):  # noqa: E501
        """run_execution_health_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_health_api(async_req=True)
        >>> result = thread.get()

        :param run_execution_health_api_input:
        :type run_execution_health_api_input: RunExecutionHealthAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunRunExecutionHealthResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_health_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_health_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_health_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_health_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param run_execution_health_api_input:
        :type run_execution_health_api_input: RunExecutionHealthAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunRunExecutionHealthResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'run_execution_health_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_health_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'run_execution_health_api_input' in local_var_params:
            body_params = local_var_params['run_execution_health_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "RunRunExecutionHealthResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/run/health', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_jupyter_idle_api(self, **kwargs):  # noqa: E501
        """run_execution_jupyter_idle_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_jupyter_idle_api(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_jupyter_idle_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_jupyter_idle_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_jupyter_idle_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_jupyter_idle_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_jupyter_idle_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "object",
        }

        return self.api_client.call_api(
            '/exec/v1/run/jupyter_idle', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_metrics_update_api(self, **kwargs):  # noqa: E501
        """run_execution_metrics_update_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_metrics_update_api(async_req=True)
        >>> result = thread.get()

        :param run_execution_metrics_update_api_input:
        :type run_execution_metrics_update_api_input: RunExecutionMetricsUpdateAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunRunExecutionMetricsUpdateResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_metrics_update_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_metrics_update_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_metrics_update_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_metrics_update_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param run_execution_metrics_update_api_input:
        :type run_execution_metrics_update_api_input: RunExecutionMetricsUpdateAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunRunExecutionMetricsUpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'run_execution_metrics_update_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_metrics_update_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'run_execution_metrics_update_api_input' in local_var_params:
            body_params = local_var_params['run_execution_metrics_update_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "RunRunExecutionMetricsUpdateResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/run/metrics', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_progress_update_api(self, **kwargs):  # noqa: E501
        """run_execution_progress_update_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_progress_update_api(async_req=True)
        >>> result = thread.get()

        :param run_execution_progress_update_api_input:
        :type run_execution_progress_update_api_input: RunExecutionProgressUpdateAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_progress_update_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_progress_update_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_progress_update_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_progress_update_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param run_execution_progress_update_api_input:
        :type run_execution_progress_update_api_input: RunExecutionProgressUpdateAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'run_execution_progress_update_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_progress_update_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'run_execution_progress_update_api_input' in local_var_params:
            body_params = local_var_params['run_execution_progress_update_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "object",
        }

        return self.api_client.call_api(
            '/exec/v1/run/progress', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_stop_idle_api(self, **kwargs):  # noqa: E501
        """run_execution_stop_idle_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_stop_idle_api(async_req=True)
        >>> result = thread.get()

        :param run_execution_stop_idle_api_input:
        :type run_execution_stop_idle_api_input: RunExecutionStopIdleAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunRunExecutionStopIdleResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_stop_idle_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_stop_idle_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_stop_idle_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_stop_idle_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param run_execution_stop_idle_api_input:
        :type run_execution_stop_idle_api_input: RunExecutionStopIdleAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunRunExecutionStopIdleResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'run_execution_stop_idle_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_stop_idle_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'run_execution_stop_idle_api_input' in local_var_params:
            body_params = local_var_params['run_execution_stop_idle_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "RunRunExecutionStopIdleResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/run/stop_idle', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_volume_v2_create_api(self, **kwargs):  # noqa: E501
        """run_execution_volume_v2_create_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_volume_v2_create_api(async_req=True)
        >>> result = thread.get()

        :param run_execution_volume_v2_create_api_input:
        :type run_execution_volume_v2_create_api_input: RunExecutionVolumeV2CreateAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_volume_v2_create_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_volume_v2_create_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_volume_v2_create_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_volume_v2_create_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param run_execution_volume_v2_create_api_input:
        :type run_execution_volume_v2_create_api_input: RunExecutionVolumeV2CreateAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'run_execution_volume_v2_create_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_volume_v2_create_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'run_execution_volume_v2_create_api_input' in local_var_params:
            body_params = local_var_params['run_execution_volume_v2_create_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "object",
        }

        return self.api_client.call_api(
            '/exec/v1/run/volume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def run_execution_wait_kill_api(self, **kwargs):  # noqa: E501
        """run_execution_wait_kill_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_wait_kill_api(async_req=True)
        >>> result = thread.get()

        :param run_execution_wait_kill_api_input:
        :type run_execution_wait_kill_api_input: RunExecutionWaitKillAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: RunRunExecutionWaitKillResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.run_execution_wait_kill_api_with_http_info(**kwargs)  # noqa: E501

    def run_execution_wait_kill_api_with_http_info(self, **kwargs):  # noqa: E501
        """run_execution_wait_kill_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.run_execution_wait_kill_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param run_execution_wait_kill_api_input:
        :type run_execution_wait_kill_api_input: RunExecutionWaitKillAPIInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(RunRunExecutionWaitKillResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'run_execution_wait_kill_api_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_execution_wait_kill_api" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'run_execution_wait_kill_api_input' in local_var_params:
            body_params = local_var_params['run_execution_wait_kill_api_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_types_map = {
            200: "RunRunExecutionWaitKillResponse",
        }

        return self.api_client.call_api(
            '/exec/v1/run/wait_kill', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmLLMDocumentEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact': 'OrmArtifact',
        'llm_document_llm_knowledge_job': 'list[OrmLLMDocumentLLMKnowledgeJob]',
        'llm_knowledge': 'OrmLLMKnowledge',
        'organization': 'OrmOrganization',
        'uploaded_by': 'OrmUser'
    }

    attribute_map = {
        'artifact': 'artifact',
        'llm_document_llm_knowledge_job': 'llm_document_llm_knowledge_job',
        'llm_knowledge': 'llm_knowledge',
        'organization': 'organization',
        'uploaded_by': 'uploaded_by'
    }

    def __init__(self, artifact=None, llm_document_llm_knowledge_job=None, llm_knowledge=None, organization=None, uploaded_by=None, local_vars_configuration=None):  # noqa: E501
        """OrmLLMDocumentEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifact = None
        self._llm_document_llm_knowledge_job = None
        self._llm_knowledge = None
        self._organization = None
        self._uploaded_by = None
        self.discriminator = None

        if artifact is not None:
            self.artifact = artifact
        if llm_document_llm_knowledge_job is not None:
            self.llm_document_llm_knowledge_job = llm_document_llm_knowledge_job
        if llm_knowledge is not None:
            self.llm_knowledge = llm_knowledge
        if organization is not None:
            self.organization = organization
        if uploaded_by is not None:
            self.uploaded_by = uploaded_by

    @property
    def artifact(self):
        """Gets the artifact of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The artifact of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmArtifact
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this OrmLLMDocumentEdges.


        :param artifact: The artifact of this OrmLLMDocumentEdges.  # noqa: E501
        :type artifact: OrmArtifact
        """

        self._artifact = artifact

    @property
    def llm_document_llm_knowledge_job(self):
        """Gets the llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: list[OrmLLMDocumentLLMKnowledgeJob]
        """
        return self._llm_document_llm_knowledge_job

    @llm_document_llm_knowledge_job.setter
    def llm_document_llm_knowledge_job(self, llm_document_llm_knowledge_job):
        """Sets the llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.


        :param llm_document_llm_knowledge_job: The llm_document_llm_knowledge_job of this OrmLLMDocumentEdges.  # noqa: E501
        :type llm_document_llm_knowledge_job: list[OrmLLMDocumentLLMKnowledgeJob]
        """

        self._llm_document_llm_knowledge_job = llm_document_llm_knowledge_job

    @property
    def llm_knowledge(self):
        """Gets the llm_knowledge of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The llm_knowledge of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmLLMKnowledge
        """
        return self._llm_knowledge

    @llm_knowledge.setter
    def llm_knowledge(self, llm_knowledge):
        """Sets the llm_knowledge of this OrmLLMDocumentEdges.


        :param llm_knowledge: The llm_knowledge of this OrmLLMDocumentEdges.  # noqa: E501
        :type llm_knowledge: OrmLLMKnowledge
        """

        self._llm_knowledge = llm_knowledge

    @property
    def organization(self):
        """Gets the organization of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The organization of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmLLMDocumentEdges.


        :param organization: The organization of this OrmLLMDocumentEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def uploaded_by(self):
        """Gets the uploaded_by of this OrmLLMDocumentEdges.  # noqa: E501


        :return: The uploaded_by of this OrmLLMDocumentEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._uploaded_by

    @uploaded_by.setter
    def uploaded_by(self, uploaded_by):
        """Sets the uploaded_by of this OrmLLMDocumentEdges.


        :param uploaded_by: The uploaded_by of this OrmLLMDocumentEdges.  # noqa: E501
        :type uploaded_by: OrmUser
        """

        self._uploaded_by = uploaded_by

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmLLMDocumentEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmLLMDocumentEdges):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmVolume(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'base_path': 'str',
        'claim_name': 'str',
        'created_dt': 'datetime',
        'edges': 'OrmVolumeEdges',
        'id': 'int',
        'immutable_slug': 'str',
        'is_read_only': 'bool',
        'is_run_plot_volume': 'bool',
        'locator_origin_artifact_id': 'int',
        'on_premise_volume_config': 'dict[str, object]',
        'role_owner_ref': 'int',
        'role_type': 'str',
        'updated_dt': 'datetime',
        'volume_operation_kind': 'str',
        'volume_organization': 'int',
        'volume_run_execution': 'int',
        'volume_storage': 'int',
        'volume_workload': 'int'
    }

    attribute_map = {
        'base_path': 'base_path',
        'claim_name': 'claim_name',
        'created_dt': 'created_dt',
        'edges': 'edges',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'is_read_only': 'is_read_only',
        'is_run_plot_volume': 'is_run_plot_volume',
        'locator_origin_artifact_id': 'locator_origin_artifact_id',
        'on_premise_volume_config': 'on_premise_volume_config',
        'role_owner_ref': 'role_owner_ref',
        'role_type': 'role_type',
        'updated_dt': 'updated_dt',
        'volume_operation_kind': 'volume_operation_kind',
        'volume_organization': 'volume_organization',
        'volume_run_execution': 'volume_run_execution',
        'volume_storage': 'volume_storage',
        'volume_workload': 'volume_workload'
    }

    def __init__(self, base_path=None, claim_name=None, created_dt=None, edges=None, id=None, immutable_slug=None, is_read_only=None, is_run_plot_volume=None, locator_origin_artifact_id=None, on_premise_volume_config=None, role_owner_ref=None, role_type=None, updated_dt=None, volume_operation_kind=None, volume_organization=None, volume_run_execution=None, volume_storage=None, volume_workload=None, local_vars_configuration=None):  # noqa: E501
        """OrmVolume - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._base_path = None
        self._claim_name = None
        self._created_dt = None
        self._edges = None
        self._id = None
        self._immutable_slug = None
        self._is_read_only = None
        self._is_run_plot_volume = None
        self._locator_origin_artifact_id = None
        self._on_premise_volume_config = None
        self._role_owner_ref = None
        self._role_type = None
        self._updated_dt = None
        self._volume_operation_kind = None
        self._volume_organization = None
        self._volume_run_execution = None
        self._volume_storage = None
        self._volume_workload = None
        self.discriminator = None

        if base_path is not None:
            self.base_path = base_path
        self.claim_name = claim_name
        if created_dt is not None:
            self.created_dt = created_dt
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if is_read_only is not None:
            self.is_read_only = is_read_only
        if is_run_plot_volume is not None:
            self.is_run_plot_volume = is_run_plot_volume
        self.locator_origin_artifact_id = locator_origin_artifact_id
        if on_premise_volume_config is not None:
            self.on_premise_volume_config = on_premise_volume_config
        if role_owner_ref is not None:
            self.role_owner_ref = role_owner_ref
        if role_type is not None:
            self.role_type = role_type
        if updated_dt is not None:
            self.updated_dt = updated_dt
        self.volume_operation_kind = volume_operation_kind
        if volume_organization is not None:
            self.volume_organization = volume_organization
        self.volume_run_execution = volume_run_execution
        self.volume_storage = volume_storage
        self.volume_workload = volume_workload

    @property
    def base_path(self):
        """Gets the base_path of this OrmVolume.  # noqa: E501


        :return: The base_path of this OrmVolume.  # noqa: E501
        :rtype: str
        """
        return self._base_path

    @base_path.setter
    def base_path(self, base_path):
        """Sets the base_path of this OrmVolume.


        :param base_path: The base_path of this OrmVolume.  # noqa: E501
        :type base_path: str
        """

        self._base_path = base_path

    @property
    def claim_name(self):
        """Gets the claim_name of this OrmVolume.  # noqa: E501


        :return: The claim_name of this OrmVolume.  # noqa: E501
        :rtype: str
        """
        return self._claim_name

    @claim_name.setter
    def claim_name(self, claim_name):
        """Sets the claim_name of this OrmVolume.


        :param claim_name: The claim_name of this OrmVolume.  # noqa: E501
        :type claim_name: str
        """

        self._claim_name = claim_name

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmVolume.  # noqa: E501


        :return: The created_dt of this OrmVolume.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmVolume.


        :param created_dt: The created_dt of this OrmVolume.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def edges(self):
        """Gets the edges of this OrmVolume.  # noqa: E501


        :return: The edges of this OrmVolume.  # noqa: E501
        :rtype: OrmVolumeEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmVolume.


        :param edges: The edges of this OrmVolume.  # noqa: E501
        :type edges: OrmVolumeEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmVolume.  # noqa: E501


        :return: The id of this OrmVolume.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmVolume.


        :param id: The id of this OrmVolume.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmVolume.  # noqa: E501


        :return: The immutable_slug of this OrmVolume.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmVolume.


        :param immutable_slug: The immutable_slug of this OrmVolume.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def is_read_only(self):
        """Gets the is_read_only of this OrmVolume.  # noqa: E501


        :return: The is_read_only of this OrmVolume.  # noqa: E501
        :rtype: bool
        """
        return self._is_read_only

    @is_read_only.setter
    def is_read_only(self, is_read_only):
        """Sets the is_read_only of this OrmVolume.


        :param is_read_only: The is_read_only of this OrmVolume.  # noqa: E501
        :type is_read_only: bool
        """

        self._is_read_only = is_read_only

    @property
    def is_run_plot_volume(self):
        """Gets the is_run_plot_volume of this OrmVolume.  # noqa: E501


        :return: The is_run_plot_volume of this OrmVolume.  # noqa: E501
        :rtype: bool
        """
        return self._is_run_plot_volume

    @is_run_plot_volume.setter
    def is_run_plot_volume(self, is_run_plot_volume):
        """Sets the is_run_plot_volume of this OrmVolume.


        :param is_run_plot_volume: The is_run_plot_volume of this OrmVolume.  # noqa: E501
        :type is_run_plot_volume: bool
        """

        self._is_run_plot_volume = is_run_plot_volume

    @property
    def locator_origin_artifact_id(self):
        """Gets the locator_origin_artifact_id of this OrmVolume.  # noqa: E501


        :return: The locator_origin_artifact_id of this OrmVolume.  # noqa: E501
        :rtype: int
        """
        return self._locator_origin_artifact_id

    @locator_origin_artifact_id.setter
    def locator_origin_artifact_id(self, locator_origin_artifact_id):
        """Sets the locator_origin_artifact_id of this OrmVolume.


        :param locator_origin_artifact_id: The locator_origin_artifact_id of this OrmVolume.  # noqa: E501
        :type locator_origin_artifact_id: int
        """

        self._locator_origin_artifact_id = locator_origin_artifact_id

    @property
    def on_premise_volume_config(self):
        """Gets the on_premise_volume_config of this OrmVolume.  # noqa: E501


        :return: The on_premise_volume_config of this OrmVolume.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._on_premise_volume_config

    @on_premise_volume_config.setter
    def on_premise_volume_config(self, on_premise_volume_config):
        """Sets the on_premise_volume_config of this OrmVolume.


        :param on_premise_volume_config: The on_premise_volume_config of this OrmVolume.  # noqa: E501
        :type on_premise_volume_config: dict[str, object]
        """

        self._on_premise_volume_config = on_premise_volume_config

    @property
    def role_owner_ref(self):
        """Gets the role_owner_ref of this OrmVolume.  # noqa: E501


        :return: The role_owner_ref of this OrmVolume.  # noqa: E501
        :rtype: int
        """
        return self._role_owner_ref

    @role_owner_ref.setter
    def role_owner_ref(self, role_owner_ref):
        """Sets the role_owner_ref of this OrmVolume.


        :param role_owner_ref: The role_owner_ref of this OrmVolume.  # noqa: E501
        :type role_owner_ref: int
        """

        self._role_owner_ref = role_owner_ref

    @property
    def role_type(self):
        """Gets the role_type of this OrmVolume.  # noqa: E501


        :return: The role_type of this OrmVolume.  # noqa: E501
        :rtype: str
        """
        return self._role_type

    @role_type.setter
    def role_type(self, role_type):
        """Sets the role_type of this OrmVolume.


        :param role_type: The role_type of this OrmVolume.  # noqa: E501
        :type role_type: str
        """

        self._role_type = role_type

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmVolume.  # noqa: E501


        :return: The updated_dt of this OrmVolume.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmVolume.


        :param updated_dt: The updated_dt of this OrmVolume.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def volume_operation_kind(self):
        """Gets the volume_operation_kind of this OrmVolume.  # noqa: E501


        :return: The volume_operation_kind of this OrmVolume.  # noqa: E501
        :rtype: str
        """
        return self._volume_operation_kind

    @volume_operation_kind.setter
    def volume_operation_kind(self, volume_operation_kind):
        """Sets the volume_operation_kind of this OrmVolume.


        :param volume_operation_kind: The volume_operation_kind of this OrmVolume.  # noqa: E501
        :type volume_operation_kind: str
        """

        self._volume_operation_kind = volume_operation_kind

    @property
    def volume_organization(self):
        """Gets the volume_organization of this OrmVolume.  # noqa: E501


        :return: The volume_organization of this OrmVolume.  # noqa: E501
        :rtype: int
        """
        return self._volume_organization

    @volume_organization.setter
    def volume_organization(self, volume_organization):
        """Sets the volume_organization of this OrmVolume.


        :param volume_organization: The volume_organization of this OrmVolume.  # noqa: E501
        :type volume_organization: int
        """

        self._volume_organization = volume_organization

    @property
    def volume_run_execution(self):
        """Gets the volume_run_execution of this OrmVolume.  # noqa: E501


        :return: The volume_run_execution of this OrmVolume.  # noqa: E501
        :rtype: int
        """
        return self._volume_run_execution

    @volume_run_execution.setter
    def volume_run_execution(self, volume_run_execution):
        """Sets the volume_run_execution of this OrmVolume.


        :param volume_run_execution: The volume_run_execution of this OrmVolume.  # noqa: E501
        :type volume_run_execution: int
        """

        self._volume_run_execution = volume_run_execution

    @property
    def volume_storage(self):
        """Gets the volume_storage of this OrmVolume.  # noqa: E501


        :return: The volume_storage of this OrmVolume.  # noqa: E501
        :rtype: int
        """
        return self._volume_storage

    @volume_storage.setter
    def volume_storage(self, volume_storage):
        """Sets the volume_storage of this OrmVolume.


        :param volume_storage: The volume_storage of this OrmVolume.  # noqa: E501
        :type volume_storage: int
        """

        self._volume_storage = volume_storage

    @property
    def volume_workload(self):
        """Gets the volume_workload of this OrmVolume.  # noqa: E501


        :return: The volume_workload of this OrmVolume.  # noqa: E501
        :rtype: int
        """
        return self._volume_workload

    @volume_workload.setter
    def volume_workload(self, volume_workload):
        """Sets the volume_workload of this OrmVolume.


        :param volume_workload: The volume_workload of this OrmVolume.  # noqa: E501
        :type volume_workload: int
        """

        self._volume_workload = volume_workload

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmVolume):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmVolume):
            return True

        return self.to_dict() != other.to_dict()
